pub struct CallSign { /* private fields */ }Expand description
In general an amateur radio callsign is of one of these forms where:
-
P – prefix character (letter or numeral, subject to exclusions below). Prefixes can be formed using one-letter, two-letters, a digit and a letter, a letter and a digit, or in rare cases a digit and two letters. There is no ITU allocation of digit-only prefixes. Letter-digit-letter prefixes are possible but there are no known cases of them being issued by national bodies.
-
N – a single numeral which separates prefix from suffix (any digit from 0 to 9). Often a cross-hatched Ø is used for the numeral zero to distinguish it from the letter O.
-
S – suffix character (letter or numeral, last character must be a letter). Digits are in practise used sparingly in suffixes and almost always for special events. This avoids confusion with separating numerals and digits in prefixes in regularly issued call signs.
From Wikipedia