pub struct CallSign { /* private fields */ }Expand description
In general an amateur radio callsign is of one of these forms where:
-
P – prefix character (letter or numeral, subject to exclusions below). Prefixes can be formed using one-letter, two-letters, a digit and a letter, a letter and a digit, or in rare cases a digit and two letters. There is no ITU allocation of digit-only prefixes. Letter-digit-letter prefixes are possible but there are no known cases of them being issued by national bodies.
-
N – a single numeral which separates prefix from suffix (any digit from 0 to 9). Often a cross-hatched Ø is used for the numeral zero to distinguish it from the letter O.
-
S – suffix character (letter or numeral, last character must be a letter). Digits are in practise used sparingly in suffixes and almost always for special events. This avoids confusion with separating numerals and digits in prefixes in regularly issued call signs.
From Wikipedia
Implementations
Sourceimpl CallSign
impl CallSign
pub fn new<S1: Into<String>, N: Into<u8>, S2: Into<String>>( prefix: S1, separator: N, suffix: S2, ) -> Self
pub fn with_ancillary_prefix<S: Into<String>>(self, prefix: S) -> Self
pub fn with_ancillary_suffix<S: Into<String>>(self, suffix: S) -> Self
pub fn ancillary_prefix(&self) -> Option<&String>
pub fn prefix(&self) -> &String
pub fn separator_numeral(&self) -> u8
pub fn suffix(&self) -> &String
pub fn ancillary_suffix(&self) -> Option<&String>
Sourcepub fn is_special(&self) -> bool
pub fn is_special(&self) -> bool
Returns true if this is a special-event or commemorative callsign — i.e. the suffix
is longer than four characters or ends with a digit.
Sourcepub fn is_prefix_non_standard(&self) -> bool
pub fn is_prefix_non_standard(&self) -> bool
Returns true if the prefix appears in the list of non-standard or
unrecognised-entity prefixes tracked by this library.
Sourcepub fn is_at_alternate_location(&self) -> bool
pub fn is_at_alternate_location(&self) -> bool
Returns true when the /A ancillary suffix indicates operation from an alternate
licensed location.
Sourcepub fn is_portable(&self) -> bool
pub fn is_portable(&self) -> bool
Returns true when the /P ancillary suffix indicates portable operation.
Sourcepub fn is_mobile(&self) -> bool
pub fn is_mobile(&self) -> bool
Returns true when the /M ancillary suffix indicates mobile operation.
Sourcepub fn is_aeronautical_mobile(&self) -> bool
pub fn is_aeronautical_mobile(&self) -> bool
Returns true when the /AM ancillary suffix indicates aeronautical mobile operation.
Sourcepub fn is_maritime_mobile(&self) -> bool
pub fn is_maritime_mobile(&self) -> bool
Returns true when the /MM ancillary suffix indicates maritime mobile operation.
Sourcepub fn is_operating_qrp(&self) -> bool
pub fn is_operating_qrp(&self) -> bool
Returns true when the /QRP ancillary suffix indicates the station is operating
at QRP power levels (typically ≤5 W).
Sourcepub fn is_fcc_license_pending(&self) -> bool
pub fn is_fcc_license_pending(&self) -> bool
Returns true when the /AG or /AE ancillary suffix indicates a pending FCC
licence upgrade.